'use strict';

exports.__esModule = true;
exports.initGit = undefined;

// Initializes the folder using `git init` and a proper `.gitignore` file
// if `git` is present in the $PATH.
let initGit = exports.initGit = (() => {
  var _ref = _asyncToGenerator(function* (target) {
    const git = (0, _.hasCommand)('git');

    if (git) {
      const cwd = target;

      yield (0, _crossSpawnPromise2.default)('git', ['init'], { cwd });
      yield (0, _crossSpawnPromise2.default)('git', ['add', '-A'], { cwd });

      let gitUser;
      let gitEmail;
      const defaultGitUser = 'skpm-bot';
      const defaultGitEmail = 'bot@skpm.io';

      try {
        gitEmail = (yield (0, _crossSpawnPromise2.default)('git', ['config', 'user.email'])).toString();
      } catch (e) {
        gitEmail = defaultGitEmail;
      }

      try {
        gitUser = (yield (0, _crossSpawnPromise2.default)('git', ['config', 'user.name'])).toString();
      } catch (e) {
        gitUser = defaultGitUser;
      }

      yield (0, _crossSpawnPromise2.default)('git', ['commit', '-m', 'initial commit from skpm'], {
        cwd,
        env: {
          GIT_COMMITTER_NAME: gitUser,
          GIT_COMMITTER_EMAIL: gitEmail,
          GIT_AUTHOR_NAME: defaultGitUser,
          GIT_AUTHOR_EMAIL: defaultGitEmail
        }
      });
    } else {
      (0, _.warn)('Could not locate `git` binary in `$PATH`. Skipping!');
    }
  });

  return function initGit(_x) {
    return _ref.apply(this, arguments);
  };
})();

// Formulate Questions if `create` args are missing


exports.install = install;
exports.isMissing = isMissing;

var _crossSpawnPromise = require('cross-spawn-promise');

var _crossSpawnPromise2 = _interopRequireDefault(_crossSpawnPromise);

var _ = require('./');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function install(cwd) {
  return (0, _crossSpawnPromise2.default)('npm', ['install'], {
    cwd,
    stdio: 'ignore'
  });
}function isMissing(argv) {
  const out = [];

  const ask = (name, message, val) => {
    const type = val === undefined ? 'input' : 'confirm';
    out.push({ name, message, type, default: val });
  };

  // Required data
  !argv.dest && ask('dest', 'Directory to create the app');
  // Extra data / flags
  !argv.name && ask('name', "The plugin's name");
  !argv.force && ask('force', 'Enforce `dest` directory; will overwrite!', false);
  ask('install', 'Install dependencies', true); // defaults `true`, ask anyway
  !argv.git && ask('git', 'Initialize a `git` repository', false); // defaults `true`, ask anyway

  return out;
}